# Landscape Report
### On this page
  * [HOW is it useful?](https://help.sap.com/docs/leanix/ea/landscape-report#how-is-it-useful?)
  * [Using Drill-Down](https://help.sap.com/docs/leanix/ea/landscape-report#using-drill-down)
  * [Applying Views to Drilled-Down Fact Sheets](https://help.sap.com/docs/leanix/ea/landscape-report#applying-views-to-drilled-down-fact-sheets)
  * [Understanding Views for Fields on Related Fact Sheets](https://help.sap.com/docs/leanix/ea/landscape-report#understanding-views-for-fields-on-related-fact-sheets)
  * [Freezing Cluster Headers](https://help.sap.com/docs/leanix/ea/landscape-report#freezing-cluster-headers)
  * [Editing in Landscape Report](https://help.sap.com/docs/leanix/ea/landscape-report#editing-in-landscape-report)
  * [Tags](https://help.sap.com/docs/leanix/ea/landscape-report#tags)
  * [Relations](https://help.sap.com/docs/leanix/ea/landscape-report#relations)


View all
The landscape report in SAP LeanIX is a powerful tool that provides a high-level overview of an organization's IT landscape, whether at a specific moment or within a defined time frame. You can organize the information by business capabilities, tech categories, and many other criteria. The report features a heat map visualization that highlights areas of the landscape that require attention based on factors such as business criticality, technology age, and technical debt, thereby providing a range of insight. By using the landscape report in SAP LeanIX, organizations can make informed decisions about their IT investments.
